==> zio-aws-storagegateway_3-5.17.158.3-sources.jar: zio/aws/storagegateway/model/CreateTapeWithBarcodeRequest.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.{
  PoolId,
  TapeSize,
  KMSKey,
  TapeBarcode,
  GatewayARN
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateTapeWithBarcodeRequest(
    gatewayARN: GatewayARN,
    tapeSizeInBytes: TapeSize,
    tapeBarcode: TapeBarcode,
    kmsEncrypted: Option[Boolean] = None,
    kmsKey: Option[KMSKey] = None,
    poolId: Option[PoolId] = None,
    worm: Option[Boolean] = None,
    tags: Option[Iterable[zio.aws.storagegateway.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.CreateTapeWithBarcodeRequest = {
    import CreateTapeWithBarcodeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.CreateTapeWithBarcodeRequest
      .builder()
      .gatewayARN(GatewayARN.unwrap(gatewayARN): java.lang.String)
      .tapeSizeInBytes(TapeSize.unwrap(tapeSizeInBytes): java.lang.Long)
      .tapeBarcode(TapeBarcode.unwrap(tapeBarcode): java.lang.String)
      .optionallyWith(kmsEncrypted.map(value => value: java.lang.Boolean))(
        _.kmsEncrypted
      )
      .optionallyWith(
        kmsKey.map(value => KMSKey.unwrap(value): java.lang.String)
      )(_.kmsKey)
      .optionallyWith(
        poolId.map(value => PoolId.unwrap(value): java.lang.String)
      )(_.poolId)
      .optionallyWith(worm.map(value => value: java.lang.Boolean))(_.worm)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest.ReadOnly =
    zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest
      .wrap(buildAwsValue())
}
object CreateTapeWithBarcodeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.CreateTapeWithBarcodeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest =
      zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest(
        gatewayARN,
        tapeSizeInBytes,
        tapeBarcode,
        kmsEncrypted.map(value => value),
        kmsKey.map(value => value),
        poolId.map(value => value),
        worm.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def gatewayARN: GatewayARN
    def tapeSizeInBytes: TapeSize
    def tapeBarcode: TapeBarcode
    def kmsEncrypted: Option[Boolean]
    def kmsKey: Option[KMSKey]
    def poolId: Option[PoolId]
    def worm: Option[Boolean]
    def tags: Option[List[zio.aws.storagegateway.model.Tag.ReadOnly]]
    def getGatewayARN: ZIO[Any, Nothing, GatewayARN] = ZIO.succeed(gatewayARN)
    def getTapeSizeInBytes: ZIO[Any, Nothing, TapeSize] =
      ZIO.succeed(tapeSizeInBytes)
    def getTapeBarcode: ZIO[Any, Nothing, TapeBarcode] =
      ZIO.succeed(tapeBarcode)
    def getKmsEncrypted: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("kmsEncrypted", kmsEncrypted)
    def getKmsKey: ZIO[Any, AwsError, KMSKey] =
      AwsError.unwrapOptionField("kmsKey", kmsKey)
    def getPoolId: ZIO[Any, AwsError, PoolId] =
      AwsError.unwrapOptionField("poolId", poolId)
    def getWorm: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("worm", worm)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.storagegateway.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.CreateTapeWithBarcodeRequest
  ) extends zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest.ReadOnly {
    override val gatewayARN: GatewayARN =
      zio.aws.storagegateway.model.primitives.GatewayARN(impl.gatewayARN())
    override val tapeSizeInBytes: TapeSize =
      zio.aws.storagegateway.model.primitives.TapeSize(impl.tapeSizeInBytes())
    override val tapeBarcode: TapeBarcode =
      zio.aws.storagegateway.model.primitives.TapeBarcode(impl.tapeBarcode())
    override val kmsEncrypted: Option[Boolean] =
      scala.Option(impl.kmsEncrypted()).map(value => value: Boolean)
    override val kmsKey: Option[KMSKey] = scala
      .Option(impl.kmsKey())
      .map(value => zio.aws.storagegateway.model.primitives.KMSKey(value))
    override val poolId: Option[PoolId] = scala
      .Option(impl.poolId())
      .map(value => zio.aws.storagegateway.model.primitives.PoolId(value))
    override val worm: Option[Boolean] =
      scala.Option(impl.worm()).map(value => value: Boolean)
    override val tags: Option[List[zio.aws.storagegateway.model.Tag.ReadOnly]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.storagegateway.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.CreateTapeWithBarcodeRequest
  ): zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-storagegateway_3-5.20.7.3-sources.jar: zio/aws/storagegateway/model/CreateTapeWithBarcodeRequest.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.{
  PoolId,
  TapeSize,
  KMSKey,
  TapeBarcode,
  GatewayARN
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateTapeWithBarcodeRequest(
    gatewayARN: GatewayARN,
    tapeSizeInBytes: TapeSize,
    tapeBarcode: TapeBarcode,
    kmsEncrypted: Optional[Boolean] = Optional.Absent,
    kmsKey: Optional[KMSKey] = Optional.Absent,
    poolId: Optional[PoolId] = Optional.Absent,
    worm: Optional[Boolean] = Optional.Absent,
    tags: Optional[Iterable[zio.aws.storagegateway.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.CreateTapeWithBarcodeRequest = {
    import CreateTapeWithBarcodeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.CreateTapeWithBarcodeRequest
      .builder()
      .gatewayARN(GatewayARN.unwrap(gatewayARN): java.lang.String)
      .tapeSizeInBytes(TapeSize.unwrap(tapeSizeInBytes): java.lang.Long)
      .tapeBarcode(TapeBarcode.unwrap(tapeBarcode): java.lang.String)
      .optionallyWith(kmsEncrypted.map(value => value: java.lang.Boolean))(
        _.kmsEncrypted
      )
      .optionallyWith(
        kmsKey.map(value => KMSKey.unwrap(value): java.lang.String)
      )(_.kmsKey)
      .optionallyWith(
        poolId.map(value => PoolId.unwrap(value): java.lang.String)
      )(_.poolId)
      .optionallyWith(worm.map(value => value: java.lang.Boolean))(_.worm)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest.ReadOnly =
    zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest
      .wrap(buildAwsValue())
}
object CreateTapeWithBarcodeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.CreateTapeWithBarcodeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest =
      zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest(
        gatewayARN,
        tapeSizeInBytes,
        tapeBarcode,
        kmsEncrypted.map(value => value),
        kmsKey.map(value => value),
        poolId.map(value => value),
        worm.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def gatewayARN: GatewayARN
    def tapeSizeInBytes: TapeSize
    def tapeBarcode: TapeBarcode
    def kmsEncrypted: Optional[Boolean]
    def kmsKey: Optional[KMSKey]
    def poolId: Optional[PoolId]
    def worm: Optional[Boolean]
    def tags: Optional[List[zio.aws.storagegateway.model.Tag.ReadOnly]]
    def getGatewayARN: ZIO[Any, Nothing, GatewayARN] = ZIO.succeed(gatewayARN)
    def getTapeSizeInBytes: ZIO[Any, Nothing, TapeSize] =
      ZIO.succeed(tapeSizeInBytes)
    def getTapeBarcode: ZIO[Any, Nothing, TapeBarcode] =
      ZIO.succeed(tapeBarcode)
    def getKmsEncrypted: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("kmsEncrypted", kmsEncrypted)
    def getKmsKey: ZIO[Any, AwsError, KMSKey] =
      AwsError.unwrapOptionField("kmsKey", kmsKey)
    def getPoolId: ZIO[Any, AwsError, PoolId] =
      AwsError.unwrapOptionField("poolId", poolId)
    def getWorm: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("worm", worm)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.storagegateway.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.CreateTapeWithBarcodeRequest
  ) extends zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest.ReadOnly {
    override val gatewayARN: GatewayARN =
      zio.aws.storagegateway.model.primitives.GatewayARN(impl.gatewayARN())
    override val tapeSizeInBytes: TapeSize =
      zio.aws.storagegateway.model.primitives.TapeSize(impl.tapeSizeInBytes())
    override val tapeBarcode: TapeBarcode =
      zio.aws.storagegateway.model.primitives.TapeBarcode(impl.tapeBarcode())
    override val kmsEncrypted: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.kmsEncrypted())
      .map(value => value: Boolean)
    override val kmsKey: Optional[KMSKey] = zio.aws.core.internal
      .optionalFromNullable(impl.kmsKey())
      .map(value => zio.aws.storagegateway.model.primitives.KMSKey(value))
    override val poolId: Optional[PoolId] = zio.aws.core.internal
      .optionalFromNullable(impl.poolId())
      .map(value => zio.aws.storagegateway.model.primitives.PoolId(value))
    override val worm: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.worm())
      .map(value => value: Boolean)
    override val tags
        : Optional[List[zio.aws.storagegateway.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.storagegateway.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.CreateTapeWithBarcodeRequest
  ): zio.aws.storagegateway.model.CreateTapeWithBarcodeRequest.ReadOnly =
    new Wrapper(impl)
}
